/* ---------------------------------------------------------------------- */
/* Script generated with: DeZign for Databases 13.0.4                     */
/* Target DBMS:           PostgreSQL 14                                   */
/* Project file:          PGNorthwind.dez                                 */
/* Project name:          PGNorthwind                                     */
/* Author:                                                                */
/* Script type:           Database creation script                        */
/* Created on:            2023-10-22 11:48                                */
/* ---------------------------------------------------------------------- */


/* ---------------------------------------------------------------------- */
/* Add tables                                                             */
/* ---------------------------------------------------------------------- */

/* ---------------------------------------------------------------------- */
/* Add table "northwind.categories"                                       */
/* ---------------------------------------------------------------------- */
GRANT ALL PRIVILEGES ON DATABASE nwindpg TO nwind;
   
--CREATE SCHEMA northwind AUTHORIZATION nwind;

CREATE TABLE northwind.categories (
    category_id SMALLINT  NOT NULL,
    category_name CHARACTER VARYING(15)  NOT NULL,
    description TEXT,
    picture BYTEA,
    CONSTRAINT pk_categories PRIMARY KEY (category_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.customer_demographics"                            */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.customer_demographics (
    customer_type_id CHARACTER VARYING(5)  NOT NULL,
    customer_desc TEXT,
    CONSTRAINT pk_customer_demographics PRIMARY KEY (customer_type_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.customers"                                        */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.customers (
    customer_id CHARACTER VARYING(5)  NOT NULL,
    company_name CHARACTER VARYING(40)  NOT NULL,
    contact_name CHARACTER VARYING(30),
    contact_title CHARACTER VARYING(30),
    address CHARACTER VARYING(60),
    city CHARACTER VARYING(15),
    region CHARACTER VARYING(15),
    postal_code CHARACTER VARYING(10),
    country CHARACTER VARYING(15),
    phone CHARACTER VARYING(24),
    fax CHARACTER VARYING(24),
    CONSTRAINT pk_customers PRIMARY KEY (customer_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.employees"                                        */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.employees (
    employee_id SMALLINT  NOT NULL,
    last_name CHARACTER VARYING(20)  NOT NULL,
    first_name CHARACTER VARYING(10)  NOT NULL,
    title CHARACTER VARYING(30),
    title_of_courtesy CHARACTER VARYING(25),
    birth_date DATE,
    hire_date DATE,
    address CHARACTER VARYING(60),
    city CHARACTER VARYING(15),
    region CHARACTER VARYING(15),
    postal_code CHARACTER VARYING(10),
    country CHARACTER VARYING(15),
    home_phone CHARACTER VARYING(24),
    extension CHARACTER VARYING(4),
    photo BYTEA,
    notes TEXT,
    reports_to SMALLINT,
    photo_path CHARACTER VARYING(255),
    CONSTRAINT pk_employees PRIMARY KEY (employee_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.region"                                           */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.region (
    region_id SMALLINT  NOT NULL,
    region_description CHARACTER VARYING(60)  NOT NULL,
    CONSTRAINT pk_region PRIMARY KEY (region_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.shippers"                                         */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.shippers (
    shipper_id SMALLINT  NOT NULL,
    company_name CHARACTER VARYING(40)  NOT NULL,
    phone CHARACTER VARYING(24),
    CONSTRAINT pk_shippers PRIMARY KEY (shipper_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.suppliers"                                        */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.suppliers (
    supplier_id SMALLINT  NOT NULL,
    company_name CHARACTER VARYING(40)  NOT NULL,
    contact_name CHARACTER VARYING(30),
    contact_title CHARACTER VARYING(30),
    address CHARACTER VARYING(60),
    city CHARACTER VARYING(15),
    region CHARACTER VARYING(15),
    postal_code CHARACTER VARYING(10),
    country CHARACTER VARYING(15),
    phone CHARACTER VARYING(24),
    fax CHARACTER VARYING(24),
    homepage TEXT,
    CONSTRAINT pk_suppliers PRIMARY KEY (supplier_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.territories"                                      */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.territories (
    territory_id CHARACTER VARYING(20)  NOT NULL,
    territory_description CHARACTER VARYING(60)  NOT NULL,
    region_id SMALLINT  NOT NULL,
    CONSTRAINT pk_territories PRIMARY KEY (territory_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.us_states"                                        */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.us_states (
    state_id SMALLINT  NOT NULL,
    state_name CHARACTER VARYING(100),
    state_abbr CHARACTER VARYING(2),
    state_region CHARACTER VARYING(50),
    CONSTRAINT pk_usstates PRIMARY KEY (state_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.customer_customer_demo"                           */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.customer_customer_demo (
    customer_id CHARACTER VARYING(5)  NOT NULL,
    customer_type_id CHARACTER VARYING(5)  NOT NULL,
    CONSTRAINT pk_customer_customer_demo PRIMARY KEY (customer_id, customer_type_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.employee_territories"                             */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.employee_territories (
    employee_id SMALLINT  NOT NULL,
    territory_id CHARACTER VARYING(20)  NOT NULL,
    CONSTRAINT pk_employee_territories PRIMARY KEY (employee_id, territory_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.orders"                                           */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.orders (
    order_id SMALLINT  NOT NULL,
    customer_id CHARACTER VARYING(5),
    employee_id SMALLINT,
    order_date DATE,
    required_date DATE,
    shipped_date DATE,
    ship_via SMALLINT,
    freight REAL,
    ship_name CHARACTER VARYING(40),
    ship_address CHARACTER VARYING(60),
    ship_city CHARACTER VARYING(15),
    ship_region CHARACTER VARYING(15),
    ship_postal_code CHARACTER VARYING(10),
    ship_country CHARACTER VARYING(15),
    CONSTRAINT pk_orders PRIMARY KEY (order_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.products"                                         */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.products (
    product_id SMALLINT  NOT NULL,
    product_name CHARACTER VARYING(40)  NOT NULL,
    supplier_id SMALLINT,
    category_id SMALLINT,
    quantity_per_unit CHARACTER VARYING(20),
    unit_price REAL,
    units_in_stock SMALLINT,
    units_on_order SMALLINT,
    reorder_level SMALLINT,
    discontinued INTEGER  NOT NULL,
    CONSTRAINT pk_products PRIMARY KEY (product_id)
);

/* ---------------------------------------------------------------------- */
/* Add table "northwind.order_details"                                    */
/* ---------------------------------------------------------------------- */

CREATE TABLE northwind.order_details (
    order_id SMALLINT  NOT NULL,
    product_id SMALLINT  NOT NULL,
    unit_price REAL  NOT NULL,
    quantity SMALLINT  NOT NULL,
    discount REAL  NOT NULL,
    CONSTRAINT pk_order_details PRIMARY KEY (order_id, product_id)
);

/* ---------------------------------------------------------------------- */
/* Add foreign key constraints                                            */
/* ---------------------------------------------------------------------- */

ALTER TABLE northwind.customer_customer_demo ADD CONSTRAINT fk_customer_customer_demo_customer_demographics 
    FOREIGN KEY (customer_type_id) REFERENCES northwind.customer_demographics (customer_type_id);

ALTER TABLE northwind.customer_customer_demo ADD CONSTRAINT fk_customer_customer_demo_customers 
    FOREIGN KEY (customer_id) REFERENCES northwind.customers (customer_id);

ALTER TABLE northwind.employee_territories ADD CONSTRAINT fk_employee_territories_territories 
    FOREIGN KEY (territory_id) REFERENCES northwind.territories (territory_id);

ALTER TABLE northwind.employee_territories ADD CONSTRAINT fk_employee_territories_employees 
    FOREIGN KEY (employee_id) REFERENCES northwind.employees (employee_id);

ALTER TABLE northwind.employees ADD CONSTRAINT fk_employees_employees 
    FOREIGN KEY (reports_to) REFERENCES northwind.employees (employee_id);

ALTER TABLE northwind.order_details ADD CONSTRAINT fk_order_details_products 
    FOREIGN KEY (product_id) REFERENCES northwind.products (product_id);

ALTER TABLE northwind.order_details ADD CONSTRAINT fk_order_details_orders 
    FOREIGN KEY (order_id) REFERENCES northwind.orders (order_id);

ALTER TABLE northwind.orders ADD CONSTRAINT fk_orders_customers 
    FOREIGN KEY (customer_id) REFERENCES northwind.customers (customer_id);

ALTER TABLE northwind.orders ADD CONSTRAINT fk_orders_employees 
    FOREIGN KEY (employee_id) REFERENCES northwind.employees (employee_id);

ALTER TABLE northwind.orders ADD CONSTRAINT fk_orders_shippers 
    FOREIGN KEY (ship_via) REFERENCES northwind.shippers (shipper_id);

ALTER TABLE northwind.products ADD CONSTRAINT fk_products_categories 
    FOREIGN KEY (category_id) REFERENCES northwind.categories (category_id);

ALTER TABLE northwind.products ADD CONSTRAINT fk_products_suppliers 
    FOREIGN KEY (supplier_id) REFERENCES northwind.suppliers (supplier_id);

ALTER TABLE northwind.territories ADD CONSTRAINT fk_territories_region 
    FOREIGN KEY (region_id) REFERENCES northwind.region (region_id);