-- Create view vw_Products_Above_Average_Price
create or replace view northwind.vw_products_above_average_price
as
select distinct product_name, unit_price
from products
where unit_price > (select avg(unit_price) from products)
order by unit_price;
 
-- Create view vw_Quarterly_Orders_by_Product
create or replace view northwind.vw_quarterly_orders_by_product
as
SELECT a.product_name, 
    d.company_name , 
    EXTRACT(YEAR FROM c.order_date) AS order_year,
    TO_CHAR(SUM(CASE WHEN EXTRACT(QUARTER FROM c.order_date) = 1 
        THEN b.unit_price*b.quantity*(1-b.discount) ELSE 0 END), 'FM999G999G999') AS "Qtr 1",
    TO_CHAR(SUM(CASE WHEN EXTRACT(QUARTER FROM c.order_date) = 2 
        THEN b.unit_price*b.quantity*(1-b.discount) ELSE 0 END), 'FM999G999G999') AS "Qtr 2",
    TO_CHAR(SUM(CASE WHEN EXTRACT(QUARTER FROM c.order_date) = 3 
        THEN b.unit_price*b.quantity*(1-b.discount) ELSE 0 END), 'FM999G999G999') AS "Qtr 3",
    TO_CHAR(SUM(CASE WHEN EXTRACT(QUARTER FROM c.order_date) = 4 
        THEN b.unit_price*b.quantity*(1-b.discount) ELSE 0 END), 'FM999G999G999') AS "Qtr 4" 
FROM products a 
INNER JOIN order_details b ON a.product_id = b.product_id
INNER JOIN orders c ON c.order_id = b.order_id
INNER JOIN customers d ON d.customer_id = c.customer_id 
WHERE c.order_date BETWEEN DATE '1997-01-01' AND DATE '1997-12-31'
GROUP BY a.product_name, 
    d.company_name , 
    EXTRACT(YEAR FROM c.order_date)
ORDER BY a.product_name, d.company_name;

-- Create view vw_invoice
create or replace view northwind.vw_invoice
as
select distinct b.ship_name, 
    b.ship_address, 
    b.ship_city, 
    b.ship_region, 
    b.ship_postal_code, 
    b.ship_country, 
    b.customer_id, 
    c.company_name, 
    c.address, 
    c.city, 
    c.region, 
    c.postal_code, 
    c.country, 
    concat(d.first_name,  ' ', d.last_name) as sales_person, 
    b.order_id, 
    b.order_date, 
    b.required_date, 
    b.shipped_date, 
    a.company_name as shipper_name, 
    e.product_id, 
    f.product_name, 
    e.unit_price, 
    e.quantity, 
    e.discount,
    e.unit_price * e.quantity * (1 - e.discount) as extended_price,
    b.freight
from shippers a 
inner join orders b on a.shipper_id = b.ship_via 
inner join customers c on c.customer_id = b.customer_id
inner join employees d on d.employee_id = b.employee_id
inner join order_details e on b.order_id = e.order_id
inner join Products f on f.product_id = e.product_id
order by b.ship_name;
 
-- Create view vw_units_in_stock
create or replace view northwind.vw_units_in_stock
as
select c.category_name as "Product Category", 
       case when s.Country in 
                 ('UK','Spain','Sweden','Germany','Norway',
                  'Denmark','Netherlands','Finland','Italy','France')
            then 'Europe'
            when s.country in ('USA','Canada','Brazil') 
            then 'America'
            else 'Asia-Pacific'
        end as "Supplier Continent", 
        sum(p.units_in_stock) as units_in_stock
from suppliers s 
inner join products p on p.supplier_id =s.supplier_id
inner join categories c on c.category_id = p.category_id 
group by c.category_name, 
         case when s.country in 
                 ('UK','Spain','Sweden','Germany','Norway',
                  'Denmark','Netherlands','Finland','Italy','France')
              then 'Europe'
              when s.country in ('USA','Canada','Brazil') 
              then 'America'
              else 'Asia-Pacific'
         end;
 
-- Create view vw_sales_by_category
create or replace view northwind.vw_sales_by_category
as
SELECT DISTINCT a.category_id,
                a.category_name,
                b.product_name,
                sum(ROUND((y.unit_price * y.quantity * (1 - y.discount))::decimal, 2)) AS product_sales
                --sum(y.unit_price * y.quantity * (1 - y.discount), 2)) as product_sales
FROM order_details y
         INNER JOIN orders d ON d.order_id = y.order_id
         INNER JOIN products b ON b.product_id = y.product_id
         INNER JOIN categories a ON a.category_id = b.category_id
WHERE d.order_date BETWEEN DATE '1997-01-01' AND DATE '1997-12-31'
GROUP BY a.category_id, a.category_name, b.product_name
ORDER BY a.category_name, b.product_name, product_sales;
 
-- Create view vw_10_most_expensive_products
create or replace view northwind.vw_10_most_expensive_products
as
select distinct product_name as ten_most_expensive_products, 
       unit_price
from products
order by unit_price desc
limit 10;
 
-- Create view vw_customer_supplier_by_city
create or replace view northwind.vw_customer_supplier_by_city
as
select city, company_name, contact_name, 'customers' as relation_ship 
from customers
union
select city, contact_name, contact_name, 'suppliers'
from suppliers
order by city, company_name;